==> radiance-substance-2.0.1-sources.jar: org/pushingpixels/substance/api/inputmap/SubstanceInputMap.java <==
/*
 * Copyright (c) 2005-2019 Substance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of Substance Kirill Grouchnikov nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.pushingpixels.substance.api.inputmap;

import javax.swing.UIDefaults.LazyInputMap;
import java.util.Map;
import java.util.TreeMap;

public final class SubstanceInputMap {
	private Map<String, String> mapping;

	public SubstanceInputMap() {
		this.mapping = new TreeMap<String, String>();
	}

	public void put(String keyStroke, String actionName) {
		this.mapping.put(keyStroke, actionName);
	}

	public void remove(String keyStroke) {
		this.mapping.remove(keyStroke);
	}

	public LazyInputMap getUiMap() {
		Object[] flat = new Object[2 * this.mapping.size()];
		int index = 0;
		for (Map.Entry<String, String> entry : this.mapping.entrySet()) {
			flat[index++] = entry.getKey();
			flat[index++] = entry.getValue();
		}
		return new LazyInputMap(flat);
	}
}

==> radiance-substance-2.5.0-sources.jar: org/pushingpixels/substance/api/inputmap/SubstanceInputMap.java <==
/*
 * Copyright (c) 2005-2019 Radiance Kirill Grouchnikov. All Rights Reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions are met:
 *
 *  o Redistributions of source code must retain the above copyright notice,
 *    this list of conditions and the following disclaimer.
 *
 *  o Redistributions in binary form must reproduce the above copyright notice,
 *    this list of conditions and the following disclaimer in the documentation
 *    and/or other materials provided with the distribution.
 *
 *  o Neither the name of the copyright holder nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR
 * CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS;
 * OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */
package org.pushingpixels.substance.api.inputmap;

import javax.swing.UIDefaults.LazyInputMap;
import java.util.Map;
import java.util.TreeMap;

public final class SubstanceInputMap {
	private Map<String, String> mapping;

	public SubstanceInputMap() {
		this.mapping = new TreeMap<>();
	}

	public void put(String keyStroke, String actionName) {
		this.mapping.put(keyStroke, actionName);
	}

	public void remove(String keyStroke) {
		this.mapping.remove(keyStroke);
	}

	public LazyInputMap getUiMap() {
		Object[] flat = new Object[2 * this.mapping.size()];
		int index = 0;
		for (Map.Entry<String, String> entry : this.mapping.entrySet()) {
			flat[index++] = entry.getKey();
			flat[index++] = entry.getValue();
		}
		return new LazyInputMap(flat);
	}
}
